#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['dirtyR']

package_data = \
{'': ['*']}

setup(name='dirtyR',
      version='0.0.6',
      description='very dirty...',
      author='fcatus',
      author_email='f.catus@pm.me',
      url='https://github.com/bchaselab/dirtyR',
      packages=packages,
      package_data=package_data,
      python_requires='>=3.6',
     )
